# Generated by Django 4.2.4 on 2023-08-06 08:24

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='GlobalConstant',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=512, unique=True)),
                ('key_type', models.CharField(choices=[('STR', 'Str'), ('INT', 'Int'), ('FLOAT', 'Float'), ('BOOL', 'Bool'), ('DICT', 'Dict'), ('LIST', 'List'), ('TUPLE', 'Tuple'), ('SET', 'Set')], max_length=512)),
                ('value', models.TextField()),
            ],
        ),
    ]
